@@ -3,6 +3,7 @@ import httplib
 import simplejson as json
 from error import HapiError
 import sys
+import traceback
 
 _PYTHON25 = sys.version_info < (2, 6)
 
@@ -19,7 +20,7 @@ class BaseClient(object):
 
 
         self.api_key = api_key
-        self.options = {'api_base': 'hubapi.com'}
+        self.options = {'api_base': 'api.hubapi.com'}
         if not _PYTHON25:
             self.options['timeout'] = timeout
         self.options.update(extra_options)
@@ -36,13 +37,14 @@ class BaseClient(object):
     def _get_path(self, subpath):
         raise Exception("Unimplemented get_path for BaseClient subclass!")
 
-    def _prepare_request(self, subpath, params, data, opts):
+    def _prepare_request(self, subpath, params, data, opts, doseq=False):
         params = params or {}
         params['hapikey'] = self.api_key
         if opts.get('hub_id') or opts.get('portal_id'):
             params['portalId'] = opts.get('hub_id') or opts.get('portal_id')
-        url = opts.get('url') or '/%s?%s' % (self._get_path(subpath), urllib.urlencode(params))
-        headers = {'Content-Type': opts.get('content_type') or 'application/json'}
+        url = opts.get('url') or '/%s?%s' % (self._get_path(subpath), urllib.urlencode(params, doseq))
+        headers = opts.get('headers') or {}
+        headers.update({'Content-Type': opts.get('content_type') or 'application/json'})
         if data and not isinstance(data, basestring) and headers['Content-Type']=='application/json':
             data = json.dumps(data)
 
@@ -56,7 +58,10 @@ class BaseClient(object):
         return params
 
     def _execute_request(self, conn, request):
-        result = conn.getresponse()
+        try:
+            result = conn.getresponse()
+        except:
+            raise HapiError(None, request, traceback.format_exc())
         result.body = result.read()
         
         data = result.body
@@ -75,11 +80,11 @@ class BaseClient(object):
 
         return data
 
-    def _call(self, subpath, params=None, method='GET', data=None, **options):
+    def _call(self, subpath, params=None, method='GET', data=None, doseq=False, **options):
         opts = self.options.copy()
         opts.update(options)
 
-        url, headers, data = self._prepare_request(subpath, params, data, opts)
+        url, headers, data = self._prepare_request(subpath, params, data, opts, doseq)
 
         kwargs = {}
         if not _PYTHON25:
