@@ -1,12 +1,17 @@
 from base import BaseClient
 
-KEYWORDS_API_VERSION = '1'
+KEYWORDS_API_VERSION = 'v1'
 
 class KeywordsClient(BaseClient):
     
     def _get_path(self, subpath):
-        return 'keywords/v%s/%s' % (KEYWORDS_API_VERSION, subpath)
+        return 'keywords/%s/%s' % (KEYWORDS_API_VERSION, subpath)
     
+    # Contains both list of keywords and metadata
+    def get_keywords_info(self, **options):
+        return self._call('keywords', **options)
+    
+    # *Only* returns the list of keywords, does not include additional metadata
     def get_keywords(self, **options):
         return self._call('keywords', **options)['keywords']
     
@@ -20,7 +25,10 @@ class KeywordsClient(BaseClient):
         data = []
         for keyword in keywords:
             if keyword != '':
-                data.append(dict(keyword=str(keyword)))
+                if type(keyword) is dict:
+                    data.append(keyword)
+                elif type(keyword) is str:
+                    data.append(dict(keyword=str(keyword)))
         return self._call('keywords', data=data, method='PUT', **options)['keywords']
     
     def delete_keyword(self, keyword_guid, **options):
